<?php
/* Copyright (C) 2016 John Valance - All Rights Reserved.
 You may use, distribute and modify this code under the
 terms of the BSD license. See file LICENSE.txt in the
 top-most parent folder distributed with this source code.
 If missing, please write to: johnv@div1sys.com.
 */

/**
 * Note: private constructor! This is a singleton class;
* To instantiate, you must use DB2Connection::getInstance();
* This will ensure that only one DB2 connection is created per request.
*/
class DB2Connection {
    private static $connectionResource;

    /**
     * Note: private constructor! This is a singleton class; To instantiate,
     * you must call static method DB2Connection::getInstance();
     */
    private function __construct() {
    }

    public static function getInstance()
    {
        // This is where singleton nature is defined: If connection already exists, return
        // that one. Each request will only create a single DB2 connection.
        if (!self::$connectionResource) {
            echo '<br>Connecting to DB2...';
            // Retrieve connection parameters from ini file
            $app_ini = parse_ini_file(__DIR__ . '/app_local.ini');

            self::$connectionResource =
            db2_pconnect(
                '*LOCAL',
                $app_ini['user'],
                $app_ini['pswd'],
                array('i5_naming' => DB2_I5_NAMING_ON,
                    'i5_libl' => $app_ini['libl']
                )
            );
            if (!self::$connectionResource)
                throw new Exception("Connection failed! : ". db2_conn_errormsg());
        }
        return self::$connectionResource;
    }

}
