<?php
/* Copyright (C) 2016 John Valance - All Rights Reserved.
 You may use, distribute and modify this code under the
 terms of the BSD license. See file LICENSE.txt in the
 top-most parent folder distributed with this source code.
 If missing, please write to: johnv@div1sys.com.
 */
class Customer {
    private $CUST_ID;
    private $COMPANY;
    private $FIRSTNAME;
    private $LASTNAME;
    private $CIVIL;
    private $ADDRESS;
    private $ADDR2;
    private $CITY;
    private $STATE;
    private $ZIP;
    private $COUNTRY;
    private $PHONE;
    private $FAX;

    /*
     * Static factory method - create a Customer object from DB data
     */
    public static function load(array $data) {
        $customer = new Customer;

        foreach ($data as $col => $value) {
            $setterMethod = "set$col";
            if (method_exists ( $customer, $setterMethod)) {
                $customer->$setterMethod($data[$col]);
            }
        }
        return $customer;
    }


    public function getFormattedAddress( $html = false ) {
        // HTML new line will use <br>, else use newline char (\n)
        $nl = $html ? '<br>' : "\n";
        $addr2 = trim($this->getADDR2()) == ''
                    ? ''
                    : "{$this->getADDR2()}$nl";

        $address = "{$this->getADDRESS()}$nl{$addr2}{$this->getCITY()}, {$this->getSTATE()} {$this->getZIP()} {$this->getCOUNTRY()}";
        return $address;
    }

    public function getMailingLabel( $html = false ) {
        // HTML new line will use <br>, else use newline char (\n)
        $nl = $html ? '<br>' : "\n";

        $address = $this->getFormattedAddress($html);
        $label = "{$this->getFIRSTNAME()} {$this->getLASTNAME()}
                $nl{$this->getCOMPANY()}
                $nl{$address}";

        return $label;
    }


    /*
     * GETTER METHODS
     */
    public function getCUST_ID() {
        return $this->CUST_ID;
    }

    public function getCOMPANY() {
        return $this->COMPANY;
    }

    public function getFIRSTNAME() {
        return $this->FIRSTNAME;
    }

    public function getLASTNAME() {
        return $this->LASTNAME;
    }

    public function getCIVIL() {
        return $this->CIVIL;
    }

    public function getADDRESS() {
        return $this->ADDRESS;
    }

    public function getADDR2() {
        return $this->ADDR2;
    }

    public function getCITY() {
        return $this->CITY;
    }

    public function getSTATE() {
        return $this->STATE;
    }

    public function getZIP() {
        return $this->ZIP;
    }

    public function getCOUNTRY() {
        return $this->COUNTRY;
    }

    public function getPHONE() {
        return $this->PHONE;
    }

    public function getFAX() {
        return $this->FAX;
    }

    /*
     * SETTER METHODS
     */
    public function setCUST_ID($CUST_ID) {
        if (!is_numeric($CUST_ID) || strlen(trim($CUST_ID)) > 5)
            throw new Exception('Customer ID must be an integer value, max 5 digits');

        $this->CUST_ID = $CUST_ID;
    }

    public function setCOMPANY($COMPANY) {
        $this->COMPANY = trim($COMPANY);
    }

    public function setFIRSTNAME($FIRSTNAME) {
        $this->FIRSTNAME = trim($FIRSTNAME);
    }

    public function setLASTNAME($LASTNAME) {
        $this->LASTNAME = trim($LASTNAME);
    }

    public function setCIVIL($CIVIL) {
        $this->CIVIL = trim($CIVIL);
    }

    public function setADDRESS($ADDRESS) {
        $this->ADDRESS = trim($ADDRESS);
    }

    public function setADDR2($ADDR2) {
        $this->ADDR2 = trim($ADDR2);
    }

    public function setCITY($CITY) {
        $this->CITY = trim($CITY);
    }

    public function setSTATE($STATE) {
        $this->STATE = trim($STATE);
    }

    public function setZIP($ZIP) {
        $this->ZIP = trim($ZIP);
    }

    public function setCOUNTRY($COUNTRY) {
        $this->COUNTRY = trim($COUNTRY);
    }

    public function setPHONE($PHONE) {
        $this->PHONE = trim($PHONE);
    }

    public function setFAX($FAX) {
        $this->FAX = trim($FAX);
    }


}
