<?php
/* Copyright (C) 2016 John Valance - All Rights Reserved.
   You may use, distribute and modify this code under the
   terms of the BSD license. See file LICENSE.txt in the
   top-most parent folder distributed with this source code.
   If missing, please write to: johnv@div1sys.com.
*/
class Query_Builder {
	private $columns;
	private $from;
	private $joins;
	private $where;
	private $whereValues = array();
	private $order;
	private $having;

	public function getColumns()
    { return $this->columns; }

    public function getFrom()
    { return $this->from; }

    public function getJoins()
    { return $this->joins; }

    public function getWhere()
    { return $this->where; }

    public function getWhereValues()
    { return $this->whereValues; }

    public function getOrder()
    { return $this->order; }

    public function getHaving()
    { return $this->having; }

    public function setColumns($columns)
    { $this->columns = $columns; }

    public function setFrom($from)
    { $this->from = $from; }

    public function setJoins($joins)
    { $this->joins = $joins; }

    public function setOrder($order)
    { $this->order = $order; }

    public function setHaving($having)
    { $this->having = $having; }


	public function toString() {

		$cols = " * ";
		if (trim($this->columns) != '') $cols = $this->columns;

		$string = "Select {$cols} FROM {$this->from} ";

		if (trim($this->joins) != '')
			$string .= " $this->joins ";

		if (trim($this->where) != '')
			$string .= " WHERE $this->where ";

		if (trim($this->having) != '')
			$string .= " HAVING $this->having ";

		if (trim($this->order) != '')
			$string .= " ORDER BY $this->order ";

		return $string;
	}

	public function toStringRowCount($name = 'ROW_COUNT') {
		$string = "Select COUNT(*) as $name FROM {$this->from} ";

		if (trim($this->joins) != '')
			$string .= " $this->joins ";

		if (trim($this->where) != '')
			$string .= " WHERE $this->where ";

		return $string;
	}


	public function where( $whereCondition, $logicalOper, $value = NULL ) {
		if ($logicalOper == 'or'){
			$this->orWhere($whereCondition, $value);
		} elseif ($logicalOper == 'and'){
			$this->andWhere($whereCondition, $value);
		} else {
			throw new Exception('Invalid logical operator passed to ' . __FUNCTION__ . ": $logicalOper. Value must be 'and' or 'or'.");
		}
	}

	public function andWhere( $whereCondition, $value = NULL ) {
	    $this->addWhere($whereCondition, 'AND', $value);
	}

	public function orWhere( $whereCondition, $value = NULL ) {
	    $this->addWhere($whereCondition, 'OR', $value);
	}

	private function addWhere( $whereCondition, $oper, $value = NULL) {
	    if ($this->where == '') {
    	    $this->where = " ($whereCondition) ";
    	} else {
    	    $this->where .= " $oper ($whereCondition) ";
    	}
    	if (isset($value)) {
    	    if (is_array($value)) {
    	        $this->whereValues = array_merge($this->whereValues, $value);
    	    } else {
    	        $this->whereValues[] = $value;
    	    }
    	}
	}



}