<?php
/* Copyright (C) 2016 John Valance - All Rights Reserved.
   You may use, distribute and modify this code under the
   terms of the BSD license. See file LICENSE.txt in the
   top-most parent folder distributed with this source code.
   If missing, please write to: johnv@div1sys.com.
*/
require_once 'Customer.php';
require_once 'DBMapper.php';
require_once 'Query_Builder.php';

$customerMapper = new DBMapper('Customer', 'SP_CUST', array('CUST_ID'));
$customerMapper->setHasAutoID(false);

try {
    $cust_90000 = $customerMapper->find(array('CUST_ID' => 90000));
    $customerMapper->delete($cust_90000);
} catch (Exception $e) {
    echo "<p>Exception on find/delete customer 90000 : {$e->getMessage()}</p>";
}

//------------------------------------------------------
// Find and display customers
$cust1 = $customerMapper->find(array('CUST_ID' => 1513));
echo "<h3>Find customer 1513:</h3>";
$label1 = $cust1->getMailingLabel(true);
echo "<p class='label'>$label1</p>";

$cust2 = $customerMapper->find(array('CUST_ID' => 1221));
echo "<h3>Find customer 1221:</h3>";
$label2 = $cust2->getMailingLabel(true);
echo "<p class='label'>$label2</p>";

//------------------------------------------------------
// Add new customer
$cust_JV = new Customer;
$cust_JV->setCUST_ID('90000');
$cust_JV->setCOMPANY('Division 1 Systems');
$cust_JV->setFIRSTNAME('John');
$cust_JV->setLASTNAME('Valance');
$cust_JV->setADDRESS('47 Barrett Street');
$cust_JV->setADDR2('');
$cust_JV->setCIVIL('');
$cust_JV->setCITY('So. Burlington');
$cust_JV->setSTATE('VT');
$cust_JV->setZIP('05403');
$cust_JV->setCOUNTRY('Bahamas');
$cust_JV->setPHONE('(802) 355-4024');
$cust_JV->setFAX('');
try {
    $customerMapper->insert($cust_JV);
} catch (Exception $e) {
    echo "<p>Exception on insert customer 90000 : {$e->getMessage()}</p>";
}

echo "<h3>Add customer 90000:</h3>";
$label_JV = $cust_JV->getMailingLabel(true);
echo "<p class='label'>$label_JV</p>";



//------------------------------------------------------
echo "<h3>Find all customers in Bahamas:</h3>";
$query = new Query_Builder();
$query->setFrom('SP_CUST');
$query->andWhere('COUNTRY = ?', 'Bahamas');
$query->setOrder('LASTNAME');

$count = $customerMapper->find_row_count($query);
echo "<h4>$count records found for Bahamas.</h4>";

$bahamaCusts = $customerMapper->find_multi($query);
foreach ($bahamaCusts as $cust) {
    $label = $cust->getMailingLabel(true);
    echo "<p class='label'>$label</p>";
}

//------------------------------------------------------
// DELETE INSERTED CUSTOMER
//$customerMapper->delete($cust_JV);

echo "<h3>Delete customer 90000:</h3>";
$label_JV = $cust_JV->getMailingLabel(true);
echo "<p class='label'>$label_JV</p>";

//------------------------------------------------------
echo "<h3>END OF SCRIPT!!</h3>";

?>

<style>
p.label {
	border: 1px solid darkgreen;
	background: #ffffe8;
	font-family: verdana;
	color: green;
	width: 35%;
	padding: 8px;
}
h3 { color: darkblue; font-family: arial }
</style>