<?php
/* Copyright (C) 2016 John Valance - All Rights Reserved.
 You may use, distribute and modify this code under the
 terms of the BSD license. See file LICENSE.txt in the
 top-most parent folder distributed with this source code.
 If missing, please write to: johnv@div1sys.com.
 */

// BAD - multiple connections
function getCustomers () {
    $conn = db2_connect ("*LOCAL", USER, PSWD, $conn_opts );
    db2_prepare($conn, 'select * from customer');
    // ...
}
function getItems () {
    $conn = db2_connect ("*LOCAL", USER, PSWD, $conn_opts );
    db2_prepare($conn, 'select * from items');
    // ...
}

// BETTER - one connection, passed into functions

    $conn = db2_connect ("*LOCAL", USER, PSWD, $conn_opts );
    getCustomers( $conn );
    getItems( $conn );
    //------------------------------------------------------
    function getCustomers ( $conn ) {
        db2_prepare($conn, 'select * from customer');
        // ...
    }
    function getItems ( $conn ) {
        db2_prepare($conn, 'select * from items');
        // ...
    }


// BEST - singleton class. Get single connection instance,
//                         where needed, w/o parameter passing

    require_once 'DB2Connection.php'; // singleton class

    function getCustomers( ) {
        $conn = DB2Connection::getDB2Connection();
        db2_prepare($conn, 'select * from customer');
        // ...
    }
    function getItems( ) {
        $conn = DB2Connection::getDB2Connection();
        db2_prepare($conn, 'select * from items');
        // ...
    }


$no = false;


    class DB2Connection {
        private static $connectionResource;

        // Private constructor - cannot be called outside this class!
        private function __construct() {  }

        // Static method - can be called without object instance
        public static function getDB2Connection() {
            if ( empty(self::$connectionResource) ) {
                self::$connectionResource = db2_connect(DB, USER, PSWD);
            }
            return self::$connectionResource;
        }
    }

    $db2Conn = DB2Connection::getDB2Connection();
    db2_exec($db2Conn, 'select * from items');



    class MyClass {
        private static $staticProperty;
        private $instanceProperty;

        public static function setStaticProperty( $staticValue ) {
            self::$staticProperty = $staticValue;
        }

        public function setInstanceProperty( $instanceValue ) {
            $this->instanceProperty = $instanceValue;
        }
    }

    MyClass::setStaticProperty('Look ma, no object instance!');

    $myObject1 = new MyClass();
    $myObject1->setInstanceProperty('This is one object instance.');

    $myObject2 = new MyClass();
    $myObject2->setInstanceProperty('This is a different object instance.');


?>